"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sourceLoader = exports.sharedObjectLoader = exports.resourceLoader = exports.assetsLoader = exports.lessLoader = exports.cssLoader = exports.nodeLoader = exports.sourceMapLoader = exports.javascriptLoader = void 0;
const browserslist_1 = __importDefault(require("browserslist"));
const mini_css_extract_plugin_1 = __importDefault(require("mini-css-extract-plugin"));
const child_process_1 = require("child_process");
const args_1 = require("./args");
const chalk_1 = __importDefault(require("chalk"));
function isLatestBrowserslist() {
    const browserslistVersion = require('browserslist/package.json').version;
    const command = `npm view browserslist version --json`;
    const latestBrowserslistVersion = JSON.parse((0, child_process_1.execSync)(command).toString().trim());
    return browserslistVersion === latestBrowserslistVersion;
}
const electronVersion = (() => {
    const [maj, min] = require('electron/package.json').version.split('.');
    return `${maj}.${min}`;
})();
const browserslistElectronVersion = (() => {
    const installedElectronVersion = `electron ${electronVersion}`;
    try {
        (0, browserslist_1.default)(installedElectronVersion);
        return installedElectronVersion;
    }
    catch (e) {
        if (!isLatestBrowserslist()) {
            const errorMessage = `${e.message}.
Please update browserslist in webpack-config-compass:
npm i -S -w @mongodb-js/webpack-config-compass browserslist@latest`;
            throw new Error(chalk_1.default.red(errorMessage));
        }
        return 'last 1 electron version';
    }
})();
const cloudSupportedBrowserslistConfig = 'last 1 Chrome versions, last 1 Safari versions, last 1 Firefox versions, last 1 Edge versions';
const javascriptLoader = (args, web = false) => ({
    test: /\.(mjs|c?jsx?|tsx?)$/,
    exclude: [
        /\bnode_modules\b/,
        /\bcore-js\b/,
    ],
    use: {
        loader: require.resolve('babel-loader'),
        options: {
            babelrc: false,
            sourceType: 'unambiguous',
            presets: [
                [
                    require.resolve('@babel/preset-env'),
                    {
                        targets: web
                            ? cloudSupportedBrowserslistConfig
                            : browserslistElectronVersion,
                        useBuiltIns: 'usage',
                        corejs: { version: '3.12', proposals: true },
                    },
                ],
                require.resolve('@babel/preset-react'),
                require.resolve('@babel/preset-typescript'),
            ],
            plugins: [
                [
                    require.resolve('@babel/plugin-transform-runtime'),
                    {
                        helpers: true,
                        regenerator: true,
                        corejs: false,
                    },
                ],
                [
                    require.resolve('@babel/plugin-proposal-decorators'),
                    { version: '2023-01' },
                ],
                args.coverage && [
                    'istanbul',
                    {
                        cwd: args.coverage,
                    },
                ],
                ['web', 'electron-renderer'].includes(args.target) &&
                    args.nodeEnv === 'development' &&
                    (0, args_1.isServe)(args) &&
                    args.hot &&
                    require.resolve('react-refresh/babel'),
            ].filter(Boolean),
        },
    },
});
exports.javascriptLoader = javascriptLoader;
const sourceMapLoader = (args) => ({
    test: /\.(mjs|c?jsx?|tsx?)$/,
    enforce: 'pre',
    use: [
        {
            loader: require.resolve('source-map-loader'),
            options: {
                filterSourceMappingUrl() {
                    return args.env.WEBPACK_SERVE === true ? 'consume' : 'remove';
                },
            },
        },
    ],
});
exports.sourceMapLoader = sourceMapLoader;
const nodeLoader = (_args) => ({
    test: /\.node$/,
    use: [{ loader: require.resolve('node-loader') }],
});
exports.nodeLoader = nodeLoader;
const cssLoader = (args, web = false) => ({
    test: /\.css$/,
    use: [
        args.mode === 'production' && args.target === 'electron-renderer'
            ? mini_css_extract_plugin_1.default.loader
            : { loader: require.resolve('style-loader') },
        {
            loader: require.resolve('css-loader'),
            options: {
                importLoaders: 1,
                modules: {
                    auto: true,
                    localIdentName: '[name]-[local]__[hash:base64:5]',
                },
            },
        },
        {
            loader: require.resolve('postcss-loader'),
            options: {
                postcssOptions: {
                    plugins: [
                        [
                            require.resolve('postcss-preset-env'),
                            {
                                browsers: web
                                    ? cloudSupportedBrowserslistConfig
                                    : browserslistElectronVersion,
                            },
                        ],
                    ],
                },
            },
        },
    ],
});
exports.cssLoader = cssLoader;
const lessLoader = (args) => ({
    test: /\.less$/,
    use: [
        ...(0, exports.cssLoader)(args).use,
        {
            loader: require.resolve('less-loader'),
        },
    ],
});
exports.lessLoader = lessLoader;
const assetsLoader = (_args) => ({
    test: /\.(jpe?g|png|svg|gif|woff|woff2|ttf|eot|otf)(\?.+?)?$/,
    type: 'asset',
    parser: {
        dataUrlCondition: {
            maxSize: 2 * 1024,
        },
    },
});
exports.assetsLoader = assetsLoader;
const resourceLoader = (_args) => ({
    test: /\.(jpe?g|png|svg|gif|woff|woff2|ttf|eot|otf)(\?.+?)?$/,
    type: 'asset/resource',
});
exports.resourceLoader = resourceLoader;
const sharedObjectLoader = (_args) => ({
    test: /\.(dylib|so|dll)(\?.+?)?$/,
    type: 'asset/resource',
});
exports.sharedObjectLoader = sharedObjectLoader;
const sourceLoader = (args) => ({
    exclude: [
        (0, exports.javascriptLoader)(args).test,
        (0, exports.nodeLoader)(args).test,
        (0, exports.cssLoader)(args).test,
        (0, exports.lessLoader)(args).test,
        (0, exports.assetsLoader)(args).test,
        (0, exports.sharedObjectLoader)(args).test,
        /\.(ejs|html)$/,
        /\.json$/,
    ],
    type: 'asset/source',
});
exports.sourceLoader = sourceLoader;
//# sourceMappingURL=loaders.js.map